@@ -10,9 +10,10 @@
 #ifndef __kamera_h__
 #define __kamera_h__
 
+#include "kcoreaddons_version.h"
 #include <KCModule>
-#include <gphoto2.h>
 #include <KPluginFactory>
+#include <gphoto2.h>
 
 class QWidget;
 class QPushButton;
@@ -33,7 +34,11 @@ class KKameraConfig : public KCModule
     friend class KameraDeviceSelectDialog;
 
 public:
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     explicit KKameraConfig(QWidget *parent, const QVariantList &);
+#else
+    explicit KKameraConfig(QObject *parent, const KPluginMetaData &md);
+#endif
     ~KKameraConfig() override;
 
     // KCModule interface methods
@@ -41,7 +46,9 @@ public:
     void save() override;
     void defaults() override;
     int buttons();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QString quickHelp() const override;
+#endif
 
 protected:
     QString suggestName(const QString &name);
@@ -64,7 +71,9 @@ private:
     void populateDeviceListView();
     void beforeCameraOperation();
     void afterCameraOperation();
-
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(5, 105, 0)
+    QWidget *widget();
+#endif
     // gphoto callbacks
     static void cbGPIdle(GPContext *context, void *data);
     static GPContextFeedback cbGPCancel(GPContext *context, void *data);
